
moralis-streams-client
======================

OpenAPI client module for moralis streams API


.. image:: https://img.shields.io/github/license/rstms/moralis-streams-client
   :target: https://img.shields.io/github/license/rstms/moralis-streams-client
   :alt: Image



.. image:: https://img.shields.io/pypi/v/moralis-streams-client.svg
   :target: https://img.shields.io/pypi/v/moralis-streams-client.svg
   :alt: Image



.. image:: https://circleci.com/gh/rstms/moralis-streams-client/tree/master.svg?style=shield
   :target: https://circleci.com/gh/rstms/moralis-streams-client/tree/master.svg?style=shield
   :alt: Image



.. image:: https://readthedocs.org/projects/moralis-streams-client/badge/?version=latest
   :target: https://readthedocs.org/projects/moralis-streams-client/badge/?version=latest
   :alt: Image



.. image:: https://pyup.io/repos/github/rstms/moralis-streams-client/shield.svg
   :target: https://pyup.io/repos/github/rstms/moralis-streams-client/shield.svg
   :alt: Image


Client module and CLI for the Moralis Streams API


* Free software: MIT license
* Documentation: https://moralis-streams-client.readthedocs.io.

Credits
-------

This package was created with Cookiecutter and ``rstms/cookiecutter-python-cli``\ , a fork of the ``audreyr/cookiecutter-pypackage`` project template.

`audreyr/cookiecutter <https://github.com/audreyr/cookiecutter>`_
`audreyr/cookiecutter-pypackage <https://github.com/audreyr/cookiecutter-pypackage>`_
`rstms/cookiecutter-python-cli <https://github.com/rstms/cookiecutter-python-cli>`_
